.. _debug:

======
debug
======

:class:`CGATReportPlugins.Renderer.Debug` is useful for
debugging purposes and will most often be used with the
:ref:`cgatreport-test` utility. It outputs the data as it
is being received from the :term:`Tracker`. The output is
a nested dictionary.

.. report:: Trackers.LabeledDataExample
   :render: debug
   
   Table with debugging information.

Options
-------

No options.
